@@ -55,7 +55,7 @@ class FPI:
         else:
             print('A transmission matrix must first be calculated or supplied')
 
-    def ms2wl(self, mirror_sep_spec, correction_factor):
+    def ms2wl(self, mirror_sep_spec, correction_factor=1.5e4):
         correction_matrix = np.zeros([self.trans_matrix.shape[1], self.trans_matrix.shape[1]])
         for j in range(self.trans_matrix.shape[1]):
             correction_matrix[j,j] = 2
@@ -67,9 +67,11 @@ class FPI:
         lams_diff = np.diff(self.lams)
         lams_diff = np.append(lams_diff, lams_diff[-1])
         temp_trans_matrix = np.copy(self.trans_matrix)
-        temp_trans_matrix = temp_trans_matrix*lams_diff
+        temp_trans_matrix = temp_trans_matrix*lams_diff[np.newaxis,:]
+        temp_trans_matrix = temp_trans_matrix/np.max(temp_trans_matrix)
 
         ws_spec = np.linalg.inv(temp_trans_matrix.T@temp_trans_matrix + correction_factor*correction_matrix)@temp_trans_matrix.T@mirror_sep_spec
+        ws_spec = ws_spec/np.max(ws_spec)
         return ws_spec
 
     def apply_camera_response(self, camera_response = []):
