@@ -1,7 +1,7 @@
 import numpy as np
 import os
 
-def import_mirror_sep_from_path(path, number_of_bands):
+def import_mirror_sep(path, number_of_bands):
     t = np.arange(0,number_of_bands,1)
     p = np.poly1d(np.load(path))
     mirror_sep = p(t)
